parse_structure — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# parse_structure

LobsterParser.parse_structure(outcar: str | None = None, poscar: str | None = None, procar: str | None = None, reciprocal_lattice: ndarray | None = None, kpoints: str | None = None, interpolation_factor: int = 1, fermi: float | None = None)

  A method to parse the electronic sturcutue information

  Parameters:

    - outcar (str, optional) – The OUTCAR filename, by default None

    - poscar (str, optional) – The POSCAR filename, by default None

    - procar (str, optional) – The POSCAR filename, by default None

    - reciprocal_lattice (np.ndarray, optional) – The reciprocal lattice matrix, by default None

    - kpoints (str, optional) – The KPOINTS file name, by default None

    - interpolation_factor (int, optional) – The interpolation factor, by default 1

    - fermi (float, optional) – The fermi energy, by default None

  Returns:

    None – None